@@ -2,11 +2,10 @@ import os
 import subprocess
 from time import sleep
 
-from aws_cdk.core import App
-import aws_cdk.aws_ec2 as ec2
-import aws_cdk.aws_efs as efs
-import aws_cdk.aws_iam as iam
-from aws_cdk.core import RemovalPolicy, Stack
+from aws_cdk import App, RemovalPolicy, Stack
+from aws_cdk import aws_ec2 as ec2
+from aws_cdk import aws_efs as efs
+from aws_cdk import aws_iam as iam
 import requests
 
 
@@ -27,6 +26,12 @@ class AWSStack():
 		app.synth()
 
 	def start(self):
+		subprocess.run(
+			f'npx cdk bootstrap --app "python -m src.substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
+			check=True,
+			shell=True
+		)
+
 		subprocess.run(
 			f'npx cdk deploy --require-approval never --app "python -m src.substrate {self.tool.name} -c {self.path} synth"',  # noqa: E501
 			check=True,
@@ -38,7 +43,8 @@ class AWSStack():
 			shell=True
 		).strip().decode('utf-8')
 
-		print('The CloudFormation stack has successfully deployed. It may take several minutes before the instance is ready to use.')  # noqa: E501
+		print('The CloudFormation stack has successfully deployed.')  # noqa: E501
+		print('\033[91mIt may take several minutes before the instance is ready to use, please wait while the instance starts.\033[0m')  # noqa: E501
 		while True:
 			print('Checking if AWS instance is ready…', end='')
 			try:
@@ -132,7 +138,8 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 			'sudo yum install -y python3',
 			'sudo mkdir -p "/mnt/efs"',
 			f'test -f "/sbin/mount.efs" && echo "{self.file_system.file_system_id}:/ /mnt/efs efs defaults,_netdev" >> /etc/fstab || echo "{self.file_system.file_system_id}.efs.{self.config["aws"].get("region", "us-east-1")}.amazonaws.com:/ /mnt/efs nfs4 nfsvers=4.1,rsize=1048576,wsize=1048576,hard,timeo=600,retrans=2,noresvport,_netdev 0 0" >> /etc/fstab',  # noqa: E501
-			'mount -a -t efs,nfs4 defaults'
+			'mount -a -t efs,nfs4 defaults',
+			'until mountpoint -d /mnt/efs; do mount -a -t efs,nfs4 defaults; done'
 		)
 
 		if _type == 'leader':
