@@ -1,6 +1,7 @@
 from .tool import Tool
 
-from .dchm import DCHM
+from .hello_world import HelloWorld
+from .nc_slicer import NetCDFSlicer
 from .ospray_studio import OSPRayStudio
 from .tapestry import Tapestry
 from .vci import VCI
