@@ -44,7 +44,7 @@ class VCI(Tool):
 
 		mounts.append(Mount('/opt/run', self.vci_path, type='bind', read_only=True))
 
-		self.port = self.config['cluster'].get('port', self.port)
+		self.port = self.config['docker'].get('port', self.port)
 		docker.services.create(
 			'evilkermit/substrate_vci:latest',
 			'python3.7',
@@ -56,7 +56,7 @@ class VCI(Tool):
 			],
 			mode=ServiceMode(
 				mode='replicated',
-				replicas=self.config['cluster'].get('replicas', 1)
+				replicas=self.config['docker'].get('replicas', 1)
 			),
 			mounts=mounts,
 			name='VCI',
@@ -67,10 +67,8 @@ class VCI(Tool):
 	def upload_to_s3(self):
 		super().upload_to_s3()
 
-		subprocess.run([
-			'aws',
-			's3',
-			'sync',
-			self.vci_path,
-			f's3://{self.config["aws"]["bucket"]}/app'
-		], check=True)
+		subprocess.run(
+			f'aws s3 sync {self.vci_path} s3://{self.config["aws"]["bucket"]}/app',
+			check=True,
+			shell=True
+		)
